import 'dart:async';
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

const MethodChannel _channel = const MethodChannel('passbase_flutter');

class PassbaseSDK {
  static set prefillUserEmail(String? value) {
    _channel.invokeMethod('setPrefillUserEmail', value);
  }

  static Future<void> initialize({
    required String publishableApiKey,
    required String customerPayload,
  }) async {
    await _channel.invokeMethod('initialize', {
      'publishableApiKey': publishableApiKey,
      'customerPayload': customerPayload,
    });
    return;
  }

  static Future<void> startVerification({
    Function? onStart,
    Function? onFinish,
    Function? onError,
    Function? onSubmitted,
  }) async {
    _channel.setMethodCallHandler((call) {
      if (call.method == "verification_error") {
        onError?.call();
      } else if (call.method == "verification_complete") {
        onFinish?.call();
      } else if (call.method == "verification_start") {
        onStart?.call();
      } else if (call.method == "verification_submitted") {
        onSubmitted?.call();
      }
      return call.arguments;
    });

    await _channel.invokeMethod('startVerification');
  }
}

class PassbaseButton extends StatelessWidget {
  final double? width;
  final double? height;
  final Function? onFinish;
  final Function? onError;
  final Function? onStart;
  final Function? onSubmitted;

  PassbaseButton({
    this.width,
    this.height,
    this.onFinish,
    this.onError,
    this.onStart,
    this.onSubmitted,
  }) {
    _channel.setMethodCallHandler((call) {
      if (call.method == "verification_error") {
        onError?.call();
      } else if (call.method == "verification_complete") {
        onFinish?.call();
      } else if (call.method == "verification_start") {
        onStart?.call();
      } else if (call.method == "verification_submitted") {
        onSubmitted?.call();
      }
      return call.arguments;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      height: height,
      child: Platform.isAndroid
          ? AndroidView(
              viewType: "PassbaseButton",
            )
          : UiKitView(
              viewType: "PassbaseButton",
            ),
    );
  }
}
